@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control::Panel::SPI
 # Description:  Base for Device panels
 # Created       Wed Feb 27 23:09:33 2013
-# SVN Id        $Id: SPI.pm 3 2015-03-12 01:07:32Z Mark Dootson $
+# SVN Id        $Id: SPI.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -23,7 +23,7 @@ use HiPi::Wx::ValidatedCheckBox;
 use HiPi::Language;
 use HiPi::Wx::ValidatedText;
 use Try::Tiny;
-use HiPi::Utils;
+use HiPi::Utils qw( uses_device_tree );
 use HiPi::Apps::Control::GroupDialog;
 use Wx::Event qw( EVT_BUTTON EVT_TEXT EVT_CHECKBOX);
 
@@ -59,6 +59,14 @@ sub new {
     
     my $list = HiPi::Apps::Control::Panel::SPI::List->new($self, $vdata);
     
+    if ( uses_device_tree ) {
+        $modules->Enable(0);
+        $grp->Enable(0);
+        $checkdev->Enable(0);
+        $buf->Enable(0);
+        $bufapply->Enable(0);
+    }
+    
     #------------------------------------------------------
     # Events
     #------------------------------------------------------
