@@ -2,7 +2,7 @@
 # Package       HiPi::Device
 # Description:  Base class for system devices
 # Created       Sat Dec 01 18:34:18 2012
-# SVN Id        $Id: Device.pm 71 2016-03-15 16:22:29Z Mark Dootson $
+# SVN Id        $Id: Device.pm 84 2016-04-03 02:08:01Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it
 #               under the terms of the GNU General Public License as published by the
@@ -51,10 +51,6 @@ sub modules_are_loaded {
 
 sub unload_modules {
     my $class = shift;
-    if ( uses_device_tree ) {
-        warn q(The uses the device tree to load device modules at boot time);
-        return;
-    }
     
     my @modules = $class->get_module_info();
     return unless ( @modules );
@@ -69,10 +65,7 @@ sub unload_modules {
 
 sub load_modules {
     my ( $class, $forceunload ) = @_;
-    if ( uses_device_tree ) {
-        warn q(The uses the device tree to load device modules at boot time);
-        return;
-    }
+    
     my @modules  = $class->get_module_info();
     return unless ( @modules );
     
