@@ -2,7 +2,7 @@
 # Package       HiPi::Device::GPIO::Pin
 # Description:  Pin
 # Created       Wed Feb 20 04:37:38 2013
-# SVN Id        $Id: Pin.pm 95 2016-04-06 03:33:36Z Mark Dootson $
+# SVN Id        $Id: Pin.pm 104 2016-04-17 17:51:37Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -22,7 +22,7 @@ use Fcntl;
 use HiPi::Constant qw( :raspberry );
 use HiPi;
 
-our $VERSION ='0.49';
+our $VERSION ='0.50';
 
 __PACKAGE__->create_accessors( qw( pinroot valfh ) );
 
@@ -145,17 +145,17 @@ sub _do_setpud {
     my $pudchars = 'error';
     
     if ( $pudval == RPI_PUD_OFF ) {
-        $pudchars = 'clear';
+        $pudchars = 'pn';
     } elsif ($pudval == RPI_PUD_UP ) {
-        $pudchars = 'up';
+        $pudchars = 'pu';
     } elsif ($pudval == RPI_PUD_DOWN ) {
-        $pudchars = 'down';
+        $pudchars = 'pd';
     } else {
         croak(qq(Incorrect PUD setting $pudval));
     }
     
     my $pinid = $self->pinid;
-    HiPi::system_sudo(qq(hipi-pud $pinid $pudchars)) and croak qq(failed to set pud restistor for $pinid : $!);
+    HiPi::system_sudo(qq(raspi-gpio set $pinid $pudchars)) and croak qq(failed to set pud resistor for $pinid : $!);
     return 1;
 }
 
