@@ -2,7 +2,7 @@
 # Package       HiPi::Device::SPI
 # Description:  Wrapper for SPI communucation
 # Created       Fri Nov 23 13:55:49 2012
-# SVN Id        $Id: SPI.pm 95 2016-04-06 03:33:36Z Mark Dootson $
+# SVN Id        $Id: SPI.pm 106 2016-04-18 16:32:43Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -24,9 +24,8 @@ use Carp;
 use HiPi::Constant qw( :raspberry );
 use HiPi;
 use HiPi::Utils qw( :all );
-use Try::Tiny;
 
-our $VERSION ='0.49';
+our $VERSION ='0.50';
 
 __PACKAGE__->create_accessors( qw ( fh fno delay speed bitsperword ) );
 
@@ -159,7 +158,7 @@ sub new {
 sub transfer {
     my($self, $buffer) = @_;
    
-    my $rval = HiPi::Device::SPI::_write_read_data(
+    my $rval = HiPi::Device::SPI::_transfer_data(
             $self->fno, $buffer, $self->delay, $self->speed, $self->bitsperword
         );
     
@@ -170,14 +169,29 @@ sub transfer {
     return $rval;
 }
 
+sub bus_transfer {
+    my $self = shift;
+    return $self->transfer( @_ ); 
+}
+
 sub set_bus_mode {
     my($self, $mode) = @_;
-    HiPi::Device::SPI::_set_spi_mode($self->fno, $mode)
+    return HiPi::Device::SPI::_set_spi_mode($self->fno, $mode);
+}
+
+sub get_bus_mode {
+    my($self) = @_;
+    return HiPi::Device::SPI::_get_spi_mode($self->fno);
 }
 
 sub set_bus_maxspeed {
     my($self, $speed) = @_;
-    HiPi::Device::SPI::_set_spi_max_speed($self->fno, $speed)
+    return HiPi::Device::SPI::_set_spi_max_speed($self->fno, $speed);
+}
+
+sub get_bus_maxspeed {
+    my($self, $speed) = @_;
+    return HiPi::Device::SPI::_get_spi_max_speed($self->fno);
 }
 
 sub close {
